import { create } from 'zustand';
import { persist } from 'zustand/middleware';

export const useOrderStore = create(
  persist(
    (set, get) => ({
      orders: [],

      initializeOrders: () => {},

      addOrder: (order) => {
        const { orders } = get();
        set({ orders: [order, ...orders] });
      },

      cancelOrder: (id) => {
        const { orders } = get();
        const updatedOrders = orders.map((order) =>
          order.id === id ? { ...order, status: 'cancelled' } : order
        );
        set({ orders: updatedOrders });
      },

      updateOrderStatus: (id, status) => {
        const { orders } = get();
        const updatedOrders = orders.map((order) =>
          order.id === id ? { ...order, status } : order
        );
        set({ orders: updatedOrders });
      },
    }),
    {
      name: 'order-storage',
    }
  )
);
